#include <adtffiltersdk/adtf_filtersdk.h>

class cMacroFilter: public adtf::filter::cFilter
{
public:
    ADTF_CLASS_ID_NAME(cMacroFilter,
                       "property_variable_macros.filter.adtf_guides.cid",
                       "Property Variable Macro Filter");
public:
    cMacroFilter()
    {
        // mark this property such that marcos are not resolved during initialization.
        m_strLogString.SetResolveMacros(false);
        m_strLogString.SetDescription("Property which will be resolved manually.");
        RegisterPropertyVariable("log_string", m_strLogString);
        
        // provide a runner to trigger resolving
        CreateRunner("log_message");
        SetDescription("log_message", "Runner pin to trigger manual resolving.");

        // common description for the component
        SetDescription("This filter shows the usage of manual macro resolving for a given property.");
    }

    tResult Process(adtf::base::tNanoSeconds, adtf::streaming::IRunner*) override
    {
        // resolve macros manually each time.
        const auto strResolved = adtf::services::adtf_resolve_macros(m_strLogString->c_str());
        LOG_INFO("%s", strResolved.GetPtr());
        RETURN_NOERROR;
    }

private:
    adtf::base::property_variable<std::string> m_strLogString;
};

// The code behind the macro creates a plugin and the main entries to the plugin DLL or shared object.
// The cPropertyFilter will be available through the plugins class factory.
ADTF_PLUGIN("Property Variable Macro Filter Plugin",
            cMacroFilter);
